import { useState, useEffect } from 'react';
import ClassSelection from './components/ClassSelection';
import PetDisplay from './components/PetDisplay';
import InteractionMenu from './components/InteractionMenu';
import NameModal from './components/modal/NameModal';
import ConfirmationModal from './components/modal/ConfirmationModal';
import { Pet, PetClassInfo } from './types/Pet';
import { fetchPets, createPet } from './services/api/api';

export default function App() {
  const [pet, setPet] = useState<Pet | null>(null);
  const [showConfirmation, setShowConfirmation] = useState(false);
  const [showNameModal, setShowNameModal] = useState(false);
  const [petName, setPetName] = useState('');
  const [selectedClass, setSelectedClass] = useState<{ key: string; info: PetClassInfo } | null>(null);

  useEffect(() => {
    const loadPets = async () => {
      try {
        const pets = await fetchPets();
        if (pets.length > 0) {
          setPet(pets[0]);
        }
      } catch (error) {
        console.error('Error loading pets:', error);
      }
    };

    loadPets();
  }, []);

  const handleClassSelect = (classKey: string, classInfo: PetClassInfo) => {
    setSelectedClass({ key: classKey, info: classInfo });
    setShowConfirmation(true);
  };

  const handleConfirm = () => {
    if (!selectedClass) return;
    setShowConfirmation(false);
    setShowNameModal(true);
    setPetName('');
  };

  const handleNameSubmit = async () => {
    if (!selectedClass || !petName.trim()) return;

    try {
      const newPet = await createPet({
        name: petName.trim(),
        class: selectedClass.key,
      });
      setPet(newPet);
      setShowNameModal(false);
    } catch (error) {
      console.error('Error creating pet:', error);
    }
  };

  const handleFeed = () => {
    if (!pet) return;
    const updatedPet = {
      ...pet,
      stats: {
        ...pet.stats,
        strength: Math.min(100, pet.stats.strength + 5)
      },
      resources: {
        ...pet.resources,
        food: Math.max(0, pet.resources.food - 10)
      }
    };
    handlePetUpdate(updatedPet);
  };

  const handlePlay = () => {
    if (!pet) return;
    const updatedPet = {
      ...pet,
      stats: {
        ...pet.stats,
        charisma: Math.min(100, pet.stats.charisma + 5)
      },
      resources: {
        ...pet.resources,
        wisdom: pet.resources.wisdom + 5
      }
    };
    handlePetUpdate(updatedPet);
  };

  const handleSleep = () => {
    if (!pet) return;
    const updatedPet = {
      ...pet,
      stats: {
        intelligence: Math.min(100, pet.stats.intelligence + 5),
        strength: Math.min(100, pet.stats.strength + 2),
        charisma: Math.min(100, pet.stats.charisma + 2)
      }
    };
    handlePetUpdate(updatedPet);
  };

  const handleCustomize = () => {
    console.log('Customize pet');
  };

  const handlePetUpdate = (updatedPet: Pet) => {
    setPet(updatedPet);
  };

  if (!pet) {
    return (
      <div className="min-h-screen bg-gray-900 text-white">
        {showNameModal && selectedClass ? (
          <NameModal
            selectedClass={selectedClass}
            petName={petName}
            setPetName={setPetName}
            handleNameSubmit={handleNameSubmit}
            setShowNameModal={setShowNameModal}
            setSelectedClass={setSelectedClass}
          />
        ) : showConfirmation && selectedClass ? (
          <ConfirmationModal
            selectedClass={selectedClass}
            handleConfirm={handleConfirm}
            setShowConfirmation={setShowConfirmation}
            setSelectedClass={setSelectedClass}
          />
        ) : (
          <ClassSelection onSelect={handleClassSelect} />
        )}
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-gray-900 text-white p-4">
      <div className="max-w-4xl mx-auto grid gap-8">
        <PetDisplay pet={pet} />
        <InteractionMenu
          pet={pet}
          onPetUpdate={handlePetUpdate}
          onFeed={handleFeed}
          onPlay={handlePlay}
          onSleep={handleSleep}
          onCustomize={handleCustomize}
        />
      </div>
    </div>
  );
}